@@ -11,7 +11,7 @@ from typedpy.fields import (
     AllOf, AnyOf, OneOf, NotField, Boolean,
     Array, Set, Map, Tuple, StructureReference,
     ImmutableField, create_typed_field, Anything,
-    SerializableField
+    SerializableField, Function
     )
 
 from typedpy.json_schema_mapping import (
@@ -20,8 +20,13 @@ from typedpy.json_schema_mapping import (
     )
 
 from typedpy.serialization import (
-    deserialize_structure, serialize
+    deserialize_structure, serialize, serialize_field, FunctionCall
 )
+
+from typedpy.serialization_wrappers import (
+    Serializer, Deserializer
+)
+
 from typedpy.extfields import (
-    DateString, DateField, TimeString, HostName, IPV4, JSONString, EmailAddress
+    DateString, DateField, DateTime, TimeString, HostName, IPV4, JSONString, EmailAddress
 )
