@@ -2,9 +2,8 @@ import json
 from datetime import datetime, date
 import re
 
-from typedpy import Field
-from typedpy.fields import TypedField, SerializableField
-from typedpy.fields import String
+from typedpy.structures import Field, TypedField
+from typedpy.fields import SerializableField, String
 
 EmailAddress = String(pattern=r"(^[a-zA-Z0-9_.+-]+@[a-zA-Z0-9-]+\.[a-zA-Z0-9]+$)")
 
@@ -88,7 +87,28 @@ class TimeString(TypedField):
 
 
 class DateField(Field, SerializableField):
-    def __init__(self, *args, date_format="%Y-%m-%d", **kwargs):
+    """
+       A datetime.date field. Can accept either a date object, or a string
+       that can be converted to a date, using the date_format in the constructor.
+
+       Arguments:
+            date_format(str): optional
+                The date format used to convert to/from a string. Default is '%Y-%m-%d'
+
+       Example:
+
+       .. code-block:: python
+
+           class Foo(Structure):
+               date = DateField
+
+           foo(date = date.today())
+           foo(date = "2020-01-31")
+
+       This is a SerializableField, thus can be serialized/deserialized.
+
+    """
+    def __init__(self, *args, date_format='%Y-%m-%d', **kwargs):
         self._date_format = date_format
         super().__init__(*args, **kwargs)
 
@@ -108,3 +128,44 @@ class DateField(Field, SerializableField):
             super().__set__(instance, value.date())
         else:
             raise TypeError("{}: expected date, datetime, or str".format(self._name))
+
+
+class DateTime(Field, SerializableField):
+    """
+        A datetime.datetime field. Can accept either a datetime object, or a string
+        that can be converted to a date, using the date_format in the constructor.
+        Arguments:
+            datetime_format(str): optional
+                The format used to convert to/from a string. Default is '%m/%d/%y %H:%M:%S'
+
+        Example:
+
+           .. code-block:: python
+
+               class Foo(Structure):
+                   timestamp = DateTime
+
+               foo(timestamp = datetime.now())
+               foo(timestamp = "01/31/20 07:15:45")
+
+        This is a SerializableField, thus can be serialized/deserialized.
+
+    """
+    def __init__(self, *args, datetime_format='%m/%d/%y %H:%M:%S', **kwargs):
+        self._datetime_format = datetime_format
+        super().__init__(*args, **kwargs)
+
+    def serialize(self, value: datetime):
+        return value.strftime(self._datetime_format)
+
+    def deserialize(self, value):
+        return datetime.strptime(value, self._datetime_format)
+
+    def __set__(self, instance, value):
+        if isinstance(value, str):
+            as_datetime = datetime.strptime(value, self._datetime_format)
+            super().__set__(instance, as_datetime)
+        elif isinstance(value, datetime):
+            super().__set__(instance, value)
+        else:
+            raise TypeError("{}: expected datetime or str".format(self._name))
