@@ -4,7 +4,7 @@ import json
 from collections.abc import Mapping
 from functools import reduce
 
-from typedpy.structures import TypedField, Structure, StructMeta
+from typedpy.structures import TypedField, Structure, _get_all_fields_by_name
 from typedpy.fields import Field, Number, String, StructureReference, \
     Array, Map, ClassReference, Enum, MultiFieldWrapper, Boolean, Tuple, Set, Anything, AnyOf, AllOf, \
     OneOf, NotField, SerializableField, SizedCollection, wrap_val, Function
@@ -51,7 +51,7 @@ def deserialize_set(set_field, value, name):
     return deserialize_list_like(set_field, set, value, name)
 
 
-def deserialize_multifield_wrapper(field, source_val, name):
+def deserialize_multifield_wrapper(field, source_val, name, keep_undefined=True):
     """
     Only primitive values are supported, otherwise deserialization is ambiguous,
     since it can only be verified when the structure is instantiated
@@ -60,7 +60,7 @@ def deserialize_multifield_wrapper(field, source_val, name):
     found_previous_match = False
     for field_option in field.get_fields():
         try:
-            deserialized = deserialize_single_field(field_option, source_val, name)
+            deserialized = deserialize_single_field(field_option, source_val, name, keep_undefined=keep_undefined)
             if isinstance(field, AnyOf):
                 return deserialized
             elif isinstance(field, NotField):
@@ -91,7 +91,7 @@ def deserialize_map(map_field, source_val, name):
     return res
 
 
-def deserialize_single_field(field, source_val, name):
+def deserialize_single_field(field, source_val, name, keep_undefined=True):
     if isinstance(field, (Number, String, Enum, Boolean)):
         field._validate(source_val)
         value = source_val
@@ -106,11 +106,11 @@ def deserialize_single_field(field, source_val, name):
     elif isinstance(field, Set):
         value = deserialize_set(field, source_val, name)
     elif isinstance(field, MultiFieldWrapper):
-        value = deserialize_multifield_wrapper(field, source_val, name)
+        value = deserialize_multifield_wrapper(field, source_val, name, keep_undefined=keep_undefined)
     elif isinstance(field, ClassReference):
-        value = deserialize_structure_internal(getattr(field, '_ty'), source_val, name)
+        value = deserialize_structure_internal(getattr(field, '_ty'), source_val, name, keep_undefined=keep_undefined)
     elif isinstance(field, StructureReference):
-        value = deserialize_structure_reference(getattr(field, '_newclass'), source_val)
+        value = deserialize_structure_reference(getattr(field, '_newclass'), source_val, keep_undefined=keep_undefined)
     elif isinstance(field, Map):
         value = deserialize_map(field, source_val, name)
     elif isinstance(field, SerializableField):
@@ -123,26 +123,17 @@ def deserialize_single_field(field, source_val, name):
     return value
 
 
-def deserialize_structure_reference(cls, the_dict: dict):
+def deserialize_structure_reference(cls, the_dict: dict, keep_undefined):
     field_by_name = dict([(k, v) for k, v in cls.__dict__.items()
                           if isinstance(v, Field) and k in the_dict])
-    kwargs = dict([(k, v) for k, v in the_dict.items() if k not in cls.__dict__])
+    kwargs = dict([(k, v) for k, v in the_dict.items() if k not in field_by_name and keep_undefined])
+
     for name, field in field_by_name.items():
         kwargs[name] = deserialize_single_field(field, the_dict[name], name)
     cls(**kwargs)
     return kwargs
 
 
-def get_all_fields_by_name(cls):
-    all_classes = reversed([c for c in cls.mro() if isinstance(c, StructMeta)])
-    all_fields_by_name = {}
-    for cl in all_classes:
-        field_by_name = dict([(k, v) for k, v in cl.__dict__.items()
-                              if isinstance(v, Field)])
-        all_fields_by_name.update(field_by_name)
-    return all_fields_by_name
-
-
 class FunctionCall(Structure):
     """
     Structure that represents a function call for the purpose of serialization mappers: \
@@ -160,7 +151,7 @@ class FunctionCall(Structure):
     _required = ['func']
 
 
-def deserialize_structure_internal(cls, the_dict, name=None, *, mapper=None, keep_undefined=False):
+def deserialize_structure_internal(cls, the_dict, name=None, *, mapper=None, keep_undefined=True):
     """
         Deserialize a dict to a Structure instance, Jackson style.
         Note the top level must be a python dict - which implies that a JSON of
@@ -185,9 +176,9 @@ def deserialize_structure_internal(cls, the_dict, name=None, *, mapper=None, kee
     """
     if mapper is None:
         mapper = {}
-    if not isinstance(mapper, (Mapping,)):
+    if not isinstance(mapper, (collections.abc.Mapping,)):
         raise TypeError("Mapper must be a mapping")
-    field_by_name = get_all_fields_by_name(cls)
+    field_by_name = _get_all_fields_by_name(cls)
 
     if not isinstance(the_dict, dict):
         props = cls.__dict__
@@ -209,7 +200,7 @@ def deserialize_structure_internal(cls, the_dict, name=None, *, mapper=None, kee
             processed_input = get_processed_input(key, mapper, the_dict)
             process = True
         if process:
-            kwargs[key] = deserialize_single_field(field, processed_input, key)
+            kwargs[key] = deserialize_single_field(field, processed_input, key, keep_undefined=keep_undefined)
 
     return cls(**kwargs)
 
@@ -347,7 +338,7 @@ def _get_mapped_value(mapper, key, items):
 def serialize_internal(structure, mapper=None, compact=False):
     if mapper is None:
         mapper = {}
-    field_by_name = get_all_fields_by_name(structure.__class__)
+    field_by_name = _get_all_fields_by_name(structure.__class__)
 
     items = structure.items() if isinstance(structure, dict) \
         else [(k, v) for (k, v) in structure.__dict__.items() if k != '_instantiated']
@@ -399,8 +390,10 @@ def serialize(structure, *, mapper=None, compact=False):
     """
     if mapper is None:
         mapper = {}
-    if not isinstance(mapper, (collections.Mapping,)):
+    if not isinstance(mapper, (collections.abc.Mapping,)):
         raise TypeError("Mapper must be a mapping")
     if not isinstance(structure, Structure):
+        if structure is None:
+            return None
         raise TypeError("serialize: must get a Structure. Got: {}".format(structure))
     return serialize_internal(structure, mapper=mapper, compact=compact)
